@@ -1,4 +1,4 @@
-use fuel_tx::crypto::Hasher;
+use fuel_crypto::Hasher;
 use fuel_vm::consts::*;
 use fuel_vm::prelude::*;
 use rand::rngs::StdRng;
